import { useState } from "react";
import type { CreateMovie } from "../../types";
import MovieForm from "./MovieForm";

interface MovieFormDataProps {
	defaultValue?: CreateMovie;
}

export default function MovieFormData({ defaultValue }: MovieFormDataProps) {
	const [loading, setLoading] = useState<boolean>(false);

	function handleOnSubmit(createMovie: CreateMovie) {
		const searchParams = new URLSearchParams(window.location.search);
		setLoading(true);

		fetch("/api/movies", {
			method: "POST",
			body: JSON.stringify(createMovie),
			credentials: "include",
			headers: {
				Accept: "application/json",
				"Content-Type": "application/json",
			},
		})
			.then((res) => res.json())
			.then((movie) => {
				console.log(movie);
			})
			.catch((err) => console.log(err))
			.finally(() => setLoading(false));
	}

	return (
		<MovieForm
			defaultValue={defaultValue}
			disabled={loading}
			onSubmit={handleOnSubmit}
		/>
	);
}
